@@ -3,25 +3,23 @@
 gperiodic - a program for browsing the periodic table and looking up
             information on elements.
 
-Copyright (C) 2000 Jonas Frantz
+Copyright (C) 1999-2002 Kyle R. Burton, 2003-2007 Jonas Frantz, 2014-2017 Alexey Loginov
  
     This file is part of gperiodic.
  
-    gdpc is free software; you can redistribute it and/or modify
+    gperiodic is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
  
-    gdpc is distributed in the hope that it will be useful,
+    gperiodic is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
  
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- 
-Authors email : jonas.frantz@helsinki.fi
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  
 */
 
@@ -37,12 +35,12 @@ Authors email : jonas.frantz@helsinki.fi
 #include "gperiodic.h"
 #include "table_data.h"
 
-#define VERSION "2.0.10"
+#define VERSION "3.0.2"
 
 #define PACKAGE "gperiodic"
 #define GPERIODIC_LOCALE_DIR "/usr/share/locale"
 
-#define HEADERTEXTLEN 40
+#define HEADERTEXTLEN 50
 
   char *optstr            = "c:hDv";		/* cmdline option string... */
   int  enable_colorscale  = 0;
@@ -66,15 +64,18 @@ int gpdata_get_atomic_number_for_symbol(const char*sym)
 void gpparse_print_element_data_for_num(int num)
 {
     int row, n, i;
+    char *escaped_header, *escaped_info;
     char fillout[HEADERTEXTLEN];
 
     printf("\n");
     for (row = 0; row < MAX_INFO_NR; row++) {
-	n = strlen(header.info[row]);
+	pango_parse_markup (_(header.info[row]), -1, 0, NULL, &escaped_header, NULL, NULL);
+	pango_parse_markup (_(table[num-1].info[row]), -1, 0, NULL, &escaped_info, NULL, NULL);
+	n = g_utf8_strlen(escaped_header, -1);
 	n = HEADERTEXTLEN - n;
 	for (i=0;i<HEADERTEXTLEN;i++) fillout[i] = ' ';
 	fillout[n] = (char) NULL;
-	printf(" %s%s%s\n", header.info[row], fillout,  table[num-1].info[row]);
+	printf(" %s%s%s\n", escaped_header, fillout, escaped_info);
     }
     printf("\n");
 }
@@ -134,7 +135,10 @@ void display_element_dialog( GtkWidget *w, gpointer d )
 
             label = gtk_label_new(NULL);
 	    if (col == 0) gtk_label_set_markup (GTK_LABEL (label), _(header.info[row]));
-            else gtk_label_set_markup (GTK_LABEL (label), _(entry->info[row]));
+            else {
+	      gtk_label_set_markup (GTK_LABEL (label), _(entry->info[row]));
+	      gtk_label_set_selectable (label, TRUE);
+	    }
 
 	    gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 	    gtk_table_attach_defaults(GTK_TABLE(tbl), label, col, col + 1, row, row + 1);
@@ -162,6 +166,7 @@ void display_element_dialog( GtkWidget *w, gpointer d )
 GCallback menu_file_exit(void)
 {
     main_window_exit(NULL,NULL);
+    return NULL;
 }
 
 
@@ -186,13 +191,21 @@ GCallback menu_help_about(void)
 
 void show_usage( void ) 
 {
-    printf(N_("GPeriodic [opts]\n"
+    printf("GPeriodic - ");
+    printf(gettext("Periodic table of the elements"));
+    printf("\n\n");
+    printf(gettext("A program for looking up data of elements from the periodic table"));
+    printf("\n\n");
+    printf(gettext("gperiodic [opts]\n"
 	   "Options are:\n"
-	   "    -h         show this help screen.\n"
+	   "    -h         show this help screen\n"
 	   "    -c <Temp>  color the elements according to their phase at\n"
-	   "               temperature <Temp> in Kelvins.\n"
-	   "    -D         dump the periodic table.\n"
+	   "               temperature <Temp> in Kelvins\n"
+	   "    -D         dump the periodic table\n"
 	   "    -v         be verbose\n\n"));
+    printf(gettext("or\n\n"
+           "gperiodic [element_symbol | atomic_number]\n"
+	   "               display information on the element with the given element symbol or atomic number\n\n"));
 }
 
 
@@ -247,6 +260,63 @@ void colorize_element(
   gtk_widget_set_style( table[i].button, table[i].style );
 }
 
+GtkWidget *create_element_button(char *info[])
+{
+  GtkWidget *vbox;
+  GtkWidget *label;
+  GtkWidget *button;
+  char *markup;
+  char *state_color;
+
+  vbox = gtk_vbox_new(FALSE, 0);
+
+  /* atomic number */
+  label = gtk_label_new(NULL);
+  markup = g_markup_printf_escaped("<span size=\"xx-small\">%s</span>",
+                                   info[NUMBER]);
+  gtk_label_set_markup(GTK_LABEL(label), markup);
+  g_free(markup);
+  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+
+  /* atomic weight */
+  label = gtk_label_new(NULL);
+  markup = g_markup_printf_escaped("<span size=\"xx-small\">%s</span>",
+                                   info[WEIGHT]);
+  gtk_label_set_markup(GTK_LABEL(label), markup);
+  g_free(markup);
+  gtk_box_pack_end(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+
+  /* symbol */
+  label = gtk_label_new(NULL);
+  /* what state is it? */
+  if (strcmp(info[MELTING], _("n/a")) == 0
+      || strcmp(info[BOILING], _("n/a")) == 0)
+  {
+    /* n/a */
+    state_color = "#7F7F7F";
+  } else if (ambientTemperature < strtod(info[MELTING], NULL)) {
+    /* solid */
+    state_color = "black";
+  } else if (ambientTemperature < strtod(info[BOILING], NULL)) {
+    /* liquid */
+    state_color = "blue";
+  } else {
+    /* gas */
+    state_color = "#CF0000";
+  }
+  markup = g_markup_printf_escaped("<span size=\"large\" weight=\"bold\" foreground=\"%s\">%s</span>",
+                                   state_color, info[SYMBOL]);
+  gtk_label_set_markup(GTK_LABEL(label), markup);
+  g_free(markup);
+  gtk_box_pack_end(GTK_BOX(vbox), label, TRUE, TRUE, 0);
+
+  /* the button */
+  button = gtk_button_new();
+  gtk_container_add(GTK_CONTAINER(button), vbox);
+
+  return button;
+}
+
 void main_prog(void)
 {
   GtkWidget *vbox;
@@ -254,7 +324,7 @@ void main_prog(void)
   int menu_num_items;
   GdkColor tooltip_color_bg, tooltip_color_fg;
   int red, gree, blue;
-  char *buff;
+  char *buff = NULL;
   int i;
 
   GtkWidget *menubar;
@@ -266,8 +336,12 @@ void main_prog(void)
   GtkActionEntry entries[] = {
 	{ "FileMenu", NULL, _("_File") },
 	{ "HelpMenu", NULL, _("_Help") },
-	{ "Exit", GTK_STOCK_OPEN, _("E_xit"), "<control>Q", _("Exit the program"), (GCallback) menu_file_exit },
-	{ "About", GTK_STOCK_HELP, _("_About"), "<control>H", _("About gperiodic"), (GCallback) menu_help_about },
+	{ "Exit", GTK_STOCK_QUIT, _("E_xit"), "<control>Q", _("Exit the program"), (GCallback) menu_file_exit },
+#if GTK_CHECK_VERSION(2,6,0)
+	{ "About", GTK_STOCK_ABOUT, _("_About"), "<control>H", _("About gperiodic"), (GCallback) menu_help_about },
+#else
+	{ "About", GTK_STOCK_HELP, _("_About"), "<control>H", _("About gperiodic"), (GCallback) menu_help_about }
+#endif /* GTK_CHECK_VERSION */
   };
 
   char *ui_description =
@@ -332,7 +406,7 @@ void main_prog(void)
 	}
 
 /* create the button */
-	table[i].button = gtk_button_new_with_label(_(table[i].info[SYMBOL]));
+	table[i].button = create_element_button(table[i].info);
 	if( !table[i].button ) {
 	    g_warning("%s(%d) %s", __FILE__, __LINE__, _("Error button was null?"));
 	    break;
@@ -345,7 +419,7 @@ void main_prog(void)
 
       table[i].style = gtk_style_copy(button_style);
 
-      _DBG( g_message(N_("%s(%d) Setting color:  %d %d %d"),__FILE__,__LINE__,
+      _DBG( g_message(gettext("%s(%d) Setting color: %d %d %d"),__FILE__,__LINE__,
         table[i].color.red,
         table[i].color.green,
         table[i].color.blue ) );
@@ -382,18 +456,22 @@ void main_prog(void)
 			 G_CALLBACK(display_element_dialog), &table[i] );
 
 /* set up a string for the tooltips */
-	buff = g_strdup_printf(N_("%s  n:%s w:%s"), _(table[i].info[NAME]),
+	buff = g_strdup_printf(gettext("%s n:%s w:%s"), _(table[i].info[NAME]),
 			       table[i].info[NUMBER], table[i].info[WEIGHT]);
 
 /* create a new tooltips object... */
+#if !GTK_CHECK_VERSION(2,12,0)
 	table[i].tooltip = gtk_tooltips_new();
 	gtk_tooltips_set_delay(table[i].tooltip,100);
 	gtk_tooltips_set_tip(table[i].tooltip,table[i].button,buff,NULL);
+#else
+	gtk_widget_set_tooltip_text(table[i].button,buff);
+#endif /* GTK_CHECK_VERSION */
 
 /* attach the button to the table */
 	gtk_table_attach(GTK_TABLE(periodic_table), table[i].button,
          		 table[i].x - 1, table[i].x, table[i].y - 1, table[i].y,
-			 GTK_FILL, GTK_FILL, 2, 2);
+			 GTK_FILL, GTK_FILL, 0, 0);
 
     }
 
@@ -420,11 +498,11 @@ int main(int argc, char** argv) {
 	switch(ch) {
 	    case 'c':
 	    if (sscanf(optarg, "%lf", &ambientTemperature) != 1) {
-		printf(N_(" Option -c error : %s is not a number.\n"), optarg);
+		printf(gettext(" Option -c error : %s is not a number.\n"), optarg);
 		return -1;
 	    }
 	    if (ambientTemperature < 0) {
-		printf(N_(" Option -c error : %s is not a valid number (must be > 0).\n"), optarg);
+		printf(gettext(" Option -c error : %s is not a valid number (must be > 0).\n"), optarg);
 		return -1;
 	    }
 	    enable_colorscale = 1;
@@ -452,12 +530,12 @@ int main(int argc, char** argv) {
 		atomicNumber = gpdata_get_atomic_number_for_symbol(argv[optind]);
 	    }
 	    if (atomicNumber == -1) {
-		printf(N_("\n Unknown element : %s. Exiting.\n\n"),argv[optind]);
+		printf(gettext("\n Unknown element : %s. Exiting.\n\n"),argv[optind]);
 		return -1;
 	    }
 	    else {
 		if (atomicNumber > ELEMENTNUM) {
-		    printf(N_("\n Element number exceeds existing elements. Exiting.\n\n"));
+		    printf(gettext("\n Element number exceeds existing elements. Exiting.\n\n"));
 		    return -1;
 		}
 		gpparse_print_element_data_for_num(atomicNumber);
