@@ -2,26 +2,24 @@
                                                                                                                                                              
 gperiodic - a program for browsing the periodic table and looking up
             information on elements.
-                                                                                                                                                             
-Copyright (C) 2000 Jonas Frantz
+
+Copyright (C) 1999-2002 Kyle R. Burton, 2003-2007 Jonas Frantz, 2014-2017 Alexey Loginov
                                                                                                                                                              
     This file is part of gperiodic.
                                                                                                                                                              
-    gdpc is free software; you can redistribute it and/or modify
+    gperiodic is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
                                                                                                                                                              
-    gdpc is distributed in the hope that it will be useful,
+    gperiodic is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
        
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-       
-Authors email : jonas.frantz@helsinki.fi
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
        
 */
 
@@ -70,7 +68,9 @@ struct table_entry {
   GdkColor    color;
   GtkStyle    *style;
   GtkWidget   *button;    /* associated gtk button */
+#if !GTK_CHECK_VERSION(2,12,0)
   GtkTooltips *tooltip;    /* associated gtk tooltip */
+#endif /* GTK_CHECK_VERSION */
 };
 
 struct colorscale {       /* table of maxcolor GkdColors */
@@ -98,11 +98,11 @@ int interactive_shell(void);
 /************************************************************************************************/
 
 #define PROGNAME "gperiodic"
-#define COPYRIGHT N_("Copyright (C) 2000 Jonas Frantz")
-#define COMMENTS N_("This program shows the periodic table of elements and information about these elements")
-#define LICENSE N_("gperiodic is free software; you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation; either version 2 of the License, or\n(at your option) any later version.\n\ngperiodic is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program; if not, write to the Free Software\nFoundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n")
-#define HOMEPAGEURL "http://www.frantz.fi/software/gperiodic.php"
-#define HOMEPAGELABEL "gperiodic homepage"
-#define AUTHORS {"Jonas Frantz", "Kyle R. Burton", "Arno W. Peters", "Costantino Ceoldo", NULL}
+#define COPYRIGHT "Copyright (C) 1999-2002 Kyle R. Burton, 2003-2007 Jonas Frantz, 2014-2017 Alexey Loginov"
+#define COMMENTS gettext("This program shows the periodic table of elements and information about these elements")
+#define LICENSE gettext("gperiodic is free software; you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation; either version 2 of the License, or\n(at your option) any later version.\n\ngperiodic is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program; if not, write to the Free Software\nFoundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA\n")
+#define HOMEPAGEURL "https://sourceforge.net/p/gperiodic"
+#define HOMEPAGELABEL gettext("gperiodic homepage")
+#define AUTHORS {"Kyle R. Burton", "Jonas Frantz", "Alexey Loginov", NULL}
 
 
